@@ -3,11 +3,12 @@ package Digest::SHA3;
 require 5.003000;
 
 use strict;
+use warnings;
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
 use Fcntl;
 use integer;
 
-$VERSION = '0.12';
+$VERSION = '0.20';
 
 require Exporter;
 require DynaLoader;
@@ -19,17 +20,6 @@ require DynaLoader;
 	sha3_384	sha3_384_base64		sha3_384_hex
 	sha3_512	sha3_512_base64		sha3_512_hex);
 
-# If possible, inherit from Digest::base
-
-eval {
-	require Digest::base;
-	push(@ISA, 'Digest::base');
-};
-
-*addfile   = \&Addfile;
-*hexdigest = \&Hexdigest;
-*b64digest = \&B64digest;
-
 # The following routines aren't time-critical, so they can be left in Perl
 
 sub new {
@@ -38,31 +28,16 @@ sub new {
 	$alg =~ s/^3?(0|224|256|384|512)$/$1/ if defined $alg;
 	if (ref($class)) {	# instance method
 		if (!defined($alg) || ($alg == $class->algorithm)) {
-			sharewind($$class);
+			sharewind($class);
 			return($class);
 		}
-		return shainit($$class, $alg) ? $class : undef;
+		return shainit($class, $alg) ? $class : undef;
 	}
 	$alg = 224 unless defined $alg;
-	my $state = shaopen($alg) || return;
-	my $self = \$state;
-	bless($self, $class);
+	return newSHA3($class, $alg);
 }
 
-sub DESTROY {
-	my $self = shift;
-	shaclose($$self);
-}
-
-sub clone {
-	my $self = shift;
-	my $state = shadup($$self) || return;
-	my $copy = \$state;
-	bless($copy, ref($self));
-	return($copy);
-}
-
-*reset = \&new;
+BEGIN { *reset = \&new }
 
 sub add_bits {
 	my($self, $data, $nbits) = @_;
@@ -71,7 +46,7 @@ sub add_bits {
 		$data = pack("B*", $data);
 	}
 	$nbits = length($data) * 8 if $nbits > length($data) * 8;
-	shawrite($data, $nbits, $$self);
+	shawrite($data, $nbits, $self);
 	return($self);
 }
 
@@ -83,22 +58,24 @@ sub _bail {
         Carp::croak($msg);
 }
 
-my $_can_T_filehandle;
+{
+	my $_can_T_filehandle;
 
-sub _istext {
-	local *FH = shift;
-	my $file = shift;
+	sub _istext {
+		local *FH = shift;
+		my $file = shift;
 
-	if (! defined $_can_T_filehandle) {
-		local $^W = 0;
-		my $istext = eval { -T FH };
-		$_can_T_filehandle = $@ ? 0 : 1;
-		return $_can_T_filehandle ? $istext : -T $file;
+		if (! defined $_can_T_filehandle) {
+			local $^W = 0;
+			my $istext = eval { -T FH };
+			$_can_T_filehandle = $@ ? 0 : 1;
+			return $_can_T_filehandle ? $istext : -T $file;
+		}
+		return $_can_T_filehandle ? -T FH : -T $file;
 	}
-	return $_can_T_filehandle ? -T FH : -T $file;
 }
 
-sub Addfile {
+sub addfile {
 	my ($self, $file, $mode) = @_;
 
 	return(_addfilebin($self, $file)) unless ref(\$file) eq 'SCALAR';
@@ -549,11 +526,15 @@ The author is particularly grateful to
 
 	Guido Bertoni
 	Joan Daemen
-	Michael Peeters 
+	Michael Peeters
 	Chris Skiscim
 	Gilles Van Assche
 
-for ideas and suggestions beneficial to the construction of this module.
+"Nothing is more fatiguing nor, in the long run, more exasperating than
+the daily effort to believe things which daily become more incredible.
+To be done with this effort is an indispensible condition of secure
+and lasting happiness."
+- Bertrand Russell
 
 =head1 COPYRIGHT AND LICENSE
 
